/**
 * 徐祥健<xuxj@hugeinfo.com.cn>
 * 2018年8月28日 10:41
 *
 */


import React from 'react';

import HeadView from '../view/HeadView';
import TableBtnView from '../view/TableBtnView';
import { Input, Button, DatePicker, Divider, Modal, message } from 'antd'
import moment from 'moment'
import Fetch from '../fetch';
import TableView from '../view/TableView';
const confirm = Modal.confirm;
const { TextArea } = Input;

function subStr (str,len) {
  if(str.length > len){
    return str.substr(0,len)+'......';
  }else {
    return str;
  }
}
export default class KnowledgeBase extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      data: [],
      loading: false,
      visible: false,
      savedate: {},
      formdata: {},
      resetKey: Date.now(),
      closeKey: Date.now()
    };
  }

  componentDidMount() {
    document.title = '智能知识库';
    this.getData();
  }
  getData = () => {
    const { formdata } = this.state;
    Fetch.getFaqList(formdata)
      .then(res => {
        for(var i=0;i<res.length;i++){
          res[i]['index'] = i+1; 
        }
        console.log(res)
        this.setState({
          data: res
        });
      });
  }
  onInputChange = ({ target: { value, name } }) => {
    this.setState(({ formdata }) => ({
      formdata: {
        ...formdata,
        [name]: value
      }
    }))
  }
  saveInputChange = ({ target: { value, name } }) => {
    this.setState(({ savedate }) => ({
      savedate: {
        ...savedate,
        [name]: value
      }
    }))
  }
  Seaech = () => {
    const { formdata } = this.state;
    Fetch.getFaqList(formdata)
      .then(res => {
        for(var i=0;i<res.length;i++){
          res[i]['index'] = i+1; 
        }
        this.setState({
          data: res
        });
      });
  }
  Reset = () => {
    this.setState({
      resetKey: Date.now(),
      formdata: {}
    }, this.getData);
  }

  showModal = (id) => {
    this.setState({
      visible: true,
    });
    Fetch.getFaqDetail(id)
      .then(res => {
        this.setState({ savedate: res })
      })
  }

  handleOk = () => {
    this.setState({ loading: true });
    const { savedate } = this.state;
    Fetch.saveFaq(savedate)
      .then(res => {
        if (res.statuscode === 1) {
          this.setState({
            loading: false,
            visible: false,
            closeKey: Date.now()
          }, this.getData);
          message.success("提交成功！")
        } else {
          message.error('保存失败，请联系管理员', 2)
        }
      });
  }

  handleCancel = () => {
    this.setState({
      closeKey: Date.now(),
      visible: false
    });
  }

  deleteItems = (id) => {
    confirm({
      title: '确认要删除这条数据吗?',
      onOk: () => {
        Fetch.deleteFaq(id)
          .then(data => {
            if (data.statuscode == 1) {
              message.success("删除成功！")
              this.setState({
                resetKey: Date.now(),
                formdata: {}
              }, this.getData);
            } else {
              message.error('删除失败，请联系管理员', 2)
            }
          })
      }
    });
  }
  render() {
    const columns = [{
      title: '序号',
      dataIndex: 'index',
      key: 'index'
    },{
      title: '问题',
      dataIndex: 'title',
      key: 'title',
      render: text => <span>{subStr(text,20)}</span>
    }, {
      title: '分类',
      dataIndex: 'faqType',
      key: 'faqType',
    }, {
      title: '具体内容',
      dataIndex: 'content',
      key: 'content',
      render: text => <span>{subStr(text,50)}</span>
    }, {
      title: '操作人',
      dataIndex: 'createrName',
      key: 'createrName',
    }, {
      title: '创建时间',
      dataIndex: 'createTime',
      key: 'createTime',
      render: text => <span>{moment(text).format("YYYY-MM-DD HH:mm")}</span>
    }, {
      title: '操作',
      key: 'action',
      render: (text, record) => (
        <span>
          <label className='theme-color' onClick={() => this.showModal(record.id)} style={{ cursor: 'pointer' }}>编辑</label>
          <Divider type="vertical" />
          <label className='theme-color' onClick={() => this.deleteItems(record.id)} style={{ cursor: 'pointer' }}>删除</label>
        </span>
      ),
    }];
    const { data, resetKey, visible, loading, savedate, closeKey } = this.state;
    return (
      
      <div className="app-page">
        <HeadView history={this.props.history} />
        <TableBtnView key={-resetKey} type="infoManage" name='智能知识信息库' btnName='新建知识' onClick={() => this.showModal('new')}>
          <Input placeholder="根据问题模糊查询" style={{ width: "200px" }} name='title' onChange={this.onInputChange} />
          <Input placeholder="根据分类模糊查询" style={{ width: "200px" }} name='faqType' onChange={this.onInputChange} />
          <Input placeholder="根据操作人模糊查询" style={{ width: "200px" }} name='createrName' onChange={this.onInputChange} />
          <DatePicker onChange={(_, value) => this.onInputChange({ target: { name: 'createTime', value } })} placeholder="根据创建时间查询"/>
          <Button type="primary" onClick={this.Seaech}>查询</Button>
          <Button onClick={this.Reset}>重置</Button>
        </TableBtnView>
        <TableView columns={columns} data={data} pageSize='10' size='default' />
        <Modal
          key={closeKey}
          confirmLoading={loading}
          visible={visible}
          title="智能知识"
          onOk={this.handleOk}
          onCancel={this.handleCancel}
          bodyStyle={{ lineHeight: 4 }}
        >
          <Input addonBefore="问题" name='title' onChange={this.saveInputChange} value={savedate.title || ''} />
          <Input addonBefore="分类" name='faqType' onChange={this.saveInputChange} value={savedate.faqType || ''} />
          <TextArea placeholder="请输入具体内容" rows='6' name='content' onChange={this.saveInputChange} value={savedate.content || ''} />
        </Modal>
      </div>
    );
  }

}
